#pragma once

#include <hyprutils/memory/WeakPtr.hpp>

//NOLINTNEXTLINE
using namespace Hyprutils::Memory;

#define SP Hyprutils::Memory::CSharedPointer
#define WP Hyprutils::Memory::CWeakPointer
#define UP Hyprutils::Memory::CUniquePointer
